@@ -1,9 +1,10 @@
+from __future__ import print_function
 import re
 import string
 import sys
 
 # types translated into "int"
-simpletypes = ["int", "gint", "guint", "gboolean", "gpointer", "size_t", "gssize", "time_t"]
+simpletypes = ["int", "gint", "guint", "gboolean", "size_t", "gssize", "time_t"]
 
 # List "excluded" contains functions that shouldn't be exported via
 # DBus.  If you remove a function from this list, please make sure
@@ -236,38 +237,38 @@ class ClientBinding (Binding):
         paramslist = ", ".join(self.paramshdr)
         if (paramslist == "") :
             paramslist = "void"
-        print "%s %s(%s)" % (self.functiontype, self.function.name,
-                             paramslist),
+        print("%s %s(%s)" % (self.functiontype, self.function.name,
+                             paramslist), end=' ')
 
         if self.headersonly:
-            print ";"
+            print(";")
             return
 
-        print "{"
+        print("{")
 
         for decl in self.decls:
-            print decl
+            print(decl)
 
-        print 'dbus_g_proxy_call(purple_proxy, "%s", NULL,' % ctopascal(self.function.name)
+        print('dbus_g_proxy_call(purple_proxy, "%s", NULL,' % ctopascal(self.function.name))
         
         for type_name in self.inputparams:
-            print "\t%s, %s, " % type_name,
-        print "G_TYPE_INVALID,"
+            print("\t%s, %s, " % type_name, end=' ')
+        print("G_TYPE_INVALID,")
 
         for type_name in self.outputparams:
-            print "\t%s, &%s, " % type_name,
-        print "G_TYPE_INVALID);"
+            print("\t%s, &%s, " % type_name, end=' ')
+        print("G_TYPE_INVALID);")
         
         for code in self.returncode:
-            print code
+            print(code)
 
-        print "}\n"
+        print("}\n")
         
 
     def definepurplestructure(self, type):
         if (self.headersonly) and (type[0] not in self.knowntypes):
-            print "struct _%s;" % type[0]
-            print "typedef struct _%s %s;" % (type[0], type[0])
+            print("struct _%s;" % type[0])
+            print("typedef struct _%s %s;" % (type[0], type[0]))
             self.knowntypes.append(type[0])
 
     def inputsimple(self, type, name, us):
@@ -353,39 +354,39 @@ class ServerBinding (Binding):
         self.argfunc = "dbus_message_get_args"
 
     def flush(self):
-        print "static DBusMessage*"
-        print "%s_DBUS(DBusMessage *message_DBUS, DBusError *error_DBUS) {" % \
-              self.function.name
+        print("static DBusMessage*")
+        print("%s_DBUS(DBusMessage *message_DBUS, DBusError *error_DBUS) {" % \
+              self.function.name)
         
-        print "\tDBusMessage *reply_DBUS;"
+        print("\tDBusMessage *reply_DBUS;")
 
         for decl in self.cdecls:
-            print decl
+            print(decl)
 
-        print "\t%s(message_DBUS, error_DBUS," % self.argfunc,
+        print("\t%s(message_DBUS, error_DBUS," % self.argfunc,end=' ')
         for param in self.cparams:
-            print "DBUS_TYPE_%s, &%s," % param,
-        print "DBUS_TYPE_INVALID);"
+            print("DBUS_TYPE_%s, &%s," % param, end=' ')
+        print("DBUS_TYPE_INVALID);")
 
-        print "\tCHECK_ERROR(error_DBUS);"
+        print("\tCHECK_ERROR(error_DBUS);")
 
         for code in self.ccode:
-            print code
+            print(code)
 
-        print "\treply_DBUS = dbus_message_new_method_return (message_DBUS);"
+        print("\treply_DBUS = dbus_message_new_method_return (message_DBUS);")
 
-        print "\tdbus_message_append_args(reply_DBUS,",
+        print("\tdbus_message_append_args(reply_DBUS,", end=' ')
         for param in self.cparamsout:
             if type(param) is str:
-                print "%s," % param,
+                print("%s," % param, end=' ')
             else:
-                print "DBUS_TYPE_%s, &%s," % param,
-        print "DBUS_TYPE_INVALID);"
+                print("DBUS_TYPE_%s, &%s," % param, end=' ')
+        print("DBUS_TYPE_INVALID);")
 
         for code in self.ccodeout:
-            print code
+            print(code)
 
-        print "\treturn reply_DBUS;\n}\n"
+        print("\treturn reply_DBUS;\n}\n")
 
 
     def addstring(self, *items):
@@ -436,7 +437,7 @@ class ServerBinding (Binding):
         self.cdecls.append("\t%s *%s;" % (type[0], name))
         self.cparams.append(("INT32", name + "_ID"))
         self.ccode.append("\tPURPLE_DBUS_ID_TO_POINTER(%s, %s_ID, %s, error_DBUS);"  % \
-                       (name, name, type[0]))
+                          (name, name, type[0]))
         self.addintype("i", name)
 
     def inputpointer(self, type, name):
@@ -539,7 +540,7 @@ class BindingSet:
 
                 
     def process(self):
-        print "/* Generated by %s.  Do not edit! */" % sys.argv[0]
+        print("/* Generated by %s.  Do not edit! */" % sys.argv[0])
 
         for line in self.inputiter:
             words = line.split()
@@ -554,7 +555,7 @@ class BindingSet:
             # empty line has been encountered
             myline = line.strip()
             while (myline.count("(") > myline.count(")")) or self.typeregexp.match(myline):
-                newline = self.inputiter.next().strip()
+                newline = next(self.inputiter).strip()
                 if len(newline) == 0:
                     break
                 myline += " " + newline
@@ -597,15 +598,15 @@ class ServerBindingSet (BindingSet):
         self.functions.append((binding.function.name, binding.dparams))
         
     def flush(self):
-        print "static PurpleDBusBinding bindings_DBUS[] = { "
+        print("static PurpleDBusBinding bindings_DBUS[] = { ")
         for function, params in self.functions:
-            print '{"%s", "%s", %s_DBUS},' % \
-                  (ctopascal(function), params, function)
+            print('{"%s", "%s", %s_DBUS},' % \
+                  (ctopascal(function), params, function))
 
-        print "{NULL, NULL, NULL}"
-        print "};"
+        print("{NULL, NULL, NULL}")
+        print("};")
 
-        print "#define PURPLE_DBUS_REGISTER_BINDINGS(handle) purple_dbus_register_bindings(handle, bindings_DBUS)"
+        print("#define PURPLE_DBUS_REGISTER_BINDINGS(handle) purple_dbus_register_bindings(handle, bindings_DBUS)")
         
 class ClientBindingSet (BindingSet):
     def __init__(self, inputfile, fprefix, headersonly):
@@ -643,7 +644,7 @@ else:
 
 if "client" in options:
     bindings = ClientBindingSet(sys.stdin, fprefix,
-                                options.has_key("headers"))
+                                "headers" in options)
 else:
     bindings = ServerBindingSet(sys.stdin, fprefix)
 bindings.process()
