@@ -499,7 +499,6 @@ void yahoo_process_chat_join(PurpleConnection *gc, struct yahoo_packet *pkt)
 	GList *roomies = NULL;
 	char *room = NULL;
 	char *topic = NULL;
-	char *someid, *someotherid, *somebase64orhashosomething, *somenegativenumber;
 
 	if (pkt->status == -1) {
 		/* We can't join */
@@ -535,39 +534,15 @@ void yahoo_process_chat_join(PurpleConnection *gc, struct yahoo_packet *pkt)
 			g_free(topic);
 			topic = yahoo_string_decode(gc, pair->value, TRUE);
 			break;
-		case 128:
-			if (g_utf8_validate(pair->value, -1, NULL)) {
-				someid = pair->value;
-			} else {
-				purple_debug_warning("yahoo", "yahoo_process_chat_join "
-						"got non-UTF-8 string for key %d\n", pair->key);
-			}
+		case 128: /* some id */
 			break;
 		case 108: /* number of joiners */
 			break;
-		case 129:
-			if (g_utf8_validate(pair->value, -1, NULL)) {
-				someotherid = pair->value;
-			} else {
-				purple_debug_warning("yahoo", "yahoo_process_chat_join "
-						"got non-UTF-8 string for key %d\n", pair->key);
-			}
+		case 129: /* some other id */
 			break;
-		case 130:
-			if (g_utf8_validate(pair->value, -1, NULL)) {
-				somebase64orhashosomething = pair->value;
-			} else {
-				purple_debug_warning("yahoo", "yahoo_process_chat_join "
-						"got non-UTF-8 string for key %d\n", pair->key);
-			}
+		case 130: /* some base64 or hash or something */
 			break;
-		case 126:
-			if (g_utf8_validate(pair->value, -1, NULL)) {
-				somenegativenumber = pair->value;
-			} else {
-				purple_debug_warning("yahoo", "yahoo_process_chat_join "
-						"got non-UTF-8 string for key %d\n", pair->key);
-			}
+		case 126: /* some negative number */
 			break;
 		case 13: /* this is 1. maybe its the type of room? (normal, user created, private, etc?) */
 			break;
