@@ -2090,8 +2090,7 @@ static int zephyr_send_im(PurpleConnection * gc, const char *who, const char *im
 
 static char* zephyr_tzc_escape_msg(const char *message)
 {
-	int pos = 0;
-	int pos2 = 0;
+	gsize pos = 0, pos2 = 0;
 	char *newmsg;
 
 	if (message && (strlen(message) > 0)) {
@@ -2122,8 +2121,7 @@ static char* zephyr_tzc_escape_msg(const char *message)
 
 char* zephyr_tzc_deescape_str(const char *message)
 {
-	int pos = 0;
-	int pos2 = 0;
+	gsize pos = 0, pos2 = 0;
 	char *newmsg;
 
 	if (message && (strlen(message) > 0)) {
